import QtQuick 1.1
import com.nokia.meego 1.0

Page {
    id: stockqueryPage
    orientationLock: PageOrientation.LockPortrait
    tools: stockqueryTools

    property int ignorefirst:0

    GwTitleBar {
        id: gwTitleBar
        titlebarName: "查询"
        height: 60//screen.currentOrientation == Screen.Portrait ? 60 : 50
    }

    Rectangle {
        id: justForGetBlackBackground
        anchors.top: gwTitleBar.bottom
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.bottom: parent.bottom
        color: "black"

        TextField {
            id: queryTextField
            anchors.top: parent.top
            anchors.topMargin: 10
            anchors.left:parent.left
            anchors.leftMargin: parent.width * 1/16
            width: 300
            focus: false
            inputMethodHints: Qt.ImhNoPredictiveText
            maximumLength: 6

            Keys.onReturnPressed: {
                stockqueryPage.ignorefirst = 0;
                if(queryTextField.text.length)
                {
                    myStockQuery.queryStockSubmit(queryTextField.text);
                }
                else
                {
                    emptyLabel.visible = true
                    emptyLabelFadeTimer.running = true
                }
                queryTextField.platformCloseSoftwareInputPanel();
                queryListView.focus = true
            }
        }

        Button {
            id: submitButton
            anchors.top: parent.top
            anchors.topMargin: 10
            anchors.right: parent.right
            anchors.rightMargin: parent.width * 1/16
            width: 80
            text: "提交"

            onClicked: {
                stockqueryPage.ignorefirst = 0;
                if(queryTextField.text.length)
                {
                    myStockQuery.queryStockSubmit(queryTextField.text);
                }
                else
                {
                    emptyLabel.visible = true
                    emptyLabelFadeTimer.running = true
                }
            }
        }

        Label {
            id: notfoundLabel
            anchors.centerIn: parent
            text: "您请求的股票不存在"
            visible: false
        }

        Label {
            id: emptyLabel
            anchors.centerIn: parent
            text: "您未输入相关代码，请重新输入"
            visible: false
        }

        Timer {
            id: notfoundLabelFadeTimer
            interval: 2000
            running: false
            repeat: false
            onTriggered: notfoundLabel.visible = false
        }

        Timer {
            id: emptyLabelFadeTimer
            interval: 2000
            running: false
            repeat: false
            onTriggered: emptyLabel.visible = false
        }

        ListView {
            id: queryListView
            anchors.top: queryTextField.bottom
            anchors.topMargin: 10
            anchors.left: parent.left
            anchors.leftMargin: parent.width * 1/16
            anchors.right: parent.right
            anchors.rightMargin: parent.width * 1/16
            anchors.bottom: parent.bottom

            delegate: Rectangle {
                            id: queryItem
                            width: queryListView.width
                            height: 50
                            color: index % 2 ? "black" : "#313131"

                            MouseArea {

                                id: mouseClick
                                anchors.fill: parent
                                onClicked: {
                                    myNetworkManager.checkNetworkAvailable2()
                                    if (myNetworkManager.stocknetworkstatus === 0)
                                    {
                                        stockqueryPage.ignorefirst = 0;
                                        appWindow.currentstocknameandcode = name
                                        queryTextField.text = "";
                                        pageStack.push(Qt.resolvedUrl("TimeSharing.qml"))
                                        myStockQuery.TriggerTimeSharing(code)
                                    }
                                }
                            }

                            Text {
                                id: codeText
                                x:0
                                width: parent.width * 2/8
                                height: parent.height
                                text: code
                                horizontalAlignment: Text.AlignLeft
                                verticalAlignment: Text.AlignVCenter
                                font.pixelSize: 25
                                color: "white"
                            }
                            Text {
                                x: parent.width * 2/8
                                width: parent.width * 5/8
                                height: parent.height
                                id: nameText
                                text: name
                                horizontalAlignment: Text.AlignHCenter
                                verticalAlignment: Text.AlignVCenter
                                font.pixelSize: 25
                                color: "white"
                            }
                            Text {
                                x: parent.width * 7/8
                                width: parent.width * 1/8
                                height: parent.height
                                id: arrowText
                                text: ">"
                                horizontalAlignment: Text.AlignRight
                                verticalAlignment: Text.AlignVCenter
                                font.pixelSize: 25
                                color: "white"
                            }
                      }
            model: queryModel
            clip: true

            onCountChanged:
            {

                if (stockqueryPage.ignorefirst)
                {
                    if (queryListView.count == 0)
                    {
                        notfoundLabel.visible = true
                        notfoundLabelFadeTimer.running = true
                    }
                    else
                    {
                        notfoundLabel.visible = false
                        notfoundLabelFadeTimer.running = false
                    }
                }
                else
                {
                    stockqueryPage.ignorefirst++;
                }
            }
        }

        ToolBarLayout {
            id: stockqueryTools
            visible: true
            ToolIcon {
                id: backIcon
                visible: true
                iconId: "toolbar-back"
                anchors.left: parent === undefined ? undefined : parent.left
                onClicked: {
                    stockqueryPage.ignorefirst = 0;
                    pageStack.pop()
                    appWindow.exitpages()
                }
            }
        }
    }//justForGetBlackBackground
}
